#
# spec file for package perl-Lexical-SealRequireHints
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Lexical-SealRequireHints
Version:        0.011
Release:        lp150.1.3
%define cpan_name Lexical-SealRequireHints
Summary:        Prevent Leakage of Lexical Hints
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Lexical-SealRequireHints/
Source0:        https://cpan.metacpan.org/authors/id/Z/ZE/ZEFRAM/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build)
%{perl_requires}

%description
This module works around two historical bugs in Perl's handling of the
'%^H' (lexical hints) variable. One bug causes lexical state in one file to
leak into another that is 'require'd/'use'd from it. This bug, [perl
#68590], was present from Perl 5.6 up to Perl 5.10, fixed in Perl 5.11.0.
The second bug causes lexical state (normally a blank '%^H' once the first
bug is fixed) to leak outwards from 'utf8.pm', if it is automatically
loaded during Unicode regular expression matching, into whatever source is
compiling at the time of the regexp match. This bug, [perl #73174], was
present from Perl 5.8.7 up to Perl 5.11.5, fixed in Perl 5.12.0.

Both of these bugs seriously damage the usability of any module relying on
'%^H' for lexical scoping, on the affected Perl versions. It is in practice
essential to work around these bugs when using such modules. On versions of
Perl that require such a workaround, this module globally changes the
behaviour of 'require', including 'use' and the implicit 'require'
performed in Unicode regular expression matching, so that it no longer
exhibits these bugs.

The workaround supplied by this module takes effect the first time its
'import' method is called. Typically this will be done by means of a 'use'
statement. This should be done as early as possible, because it only
affects 'require'/'use' statements that are compiled after the workaround
goes into effect. For 'use' statements, and 'require' statements that are
executed immediately and only once, it suffices to invoke the workaround
when loading the first module that will set up vulnerable lexical state.
Delayed-action 'require' statements, however, are more troublesome, and can
require the workaround to be loaded much earlier. Ultimately, an affected
Perl program may need to load the workaround as very nearly its first
action. Invoking this module multiple times, from multiple modules, is not
a problem: the workaround is only applied once, and applies to everything
subsequently compiled.

This module is implemented in XS, with a pure Perl backup version for
systems that can't handle XS modules. The XS version has a better chance of
playing nicely with other modules that modify 'require' handling. The pure
Perl version can't work at all on some Perl versions; users of those
versions must use the XS. On all Perl versions suffering the underlying
hint leakage bug, pure Perl hooking of 'require' breaks the use of
'require' without an explicit parameter (implicitly using '$_').

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Build.PL installdirs=vendor optimize="%{optflags}"
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Tue Jul 25 2017 coolo@suse.com
- updated to 0.011
  see /usr/share/doc/packages/perl-Lexical-SealRequireHints/Changes
  version 0.011; 2017-07-15
  * update test suite to not rely on . in @INC, which is no longer
    necessarily there from Perl 5.25.7
  * no longer include a Makefile.PL in the distribution
  * update op-munging code to the PERL_OP_PARENT-compatible style
    (though none of it is actually used on Perls new enough to support
    PERL_OP_PARENT)
  * rename internal gen_*_op() functions into a better style
  * consistently use THX_ prefix on internal function names
* Wed Mar 23 2016 coolo@suse.com
- updated to 0.010
  see /usr/share/doc/packages/perl-Lexical-SealRequireHints/Changes
  version 0.010; 2016-03-18
  * skip test with lexical $_ on Perl 5.23.4+ where that feature has
    been removed
* Mon Apr 13 2015 coolo@suse.com
- updated to 0.009
  see /usr/share/doc/packages/perl-Lexical-SealRequireHints/Changes
  version 0.009; 2015-03-20
  * in test of require for version checking, work around [perl #124135]
    which was introduced in Perl 5.21.4
  version 0.008; 2015-03-20
  * bugfix: don't localise hints around a version-number require, so that
    "use v5.10.0" can have its intentional effect of setting feature flags
  * bugfix: in pure Perl implementation, use a ($) prototype on
    CORE::GLOBAL::require, so that the argument expression will be in
    the correct context
  * better error message for refusing to use pure Perl implementation
    on Perl 5.9.4 to 5.10.0
  * document that the pure Perl implementation breaks the use of the
    implicit $_ parameter with require
  * in swash test, don't fail if utf8.pm was loaded unexpectedly early,
    as has been seen to happen on some systems
  * test idempotence
  * fix test for thread safety, which risked false negatives
  * when preemptively loading Carp and Carp::Heavy, avoid the Perl core
    bug regarding the context applied to file scope of required modules,
    in case of future versions of those modules becoming vulnerable and
    running on an old Perl
  * declare correct version for Test::More dependency
  * typo fix in documentation
  * typo fix in a comment
* Thu Feb 27 2014 coolo@suse.com
- initial package 0.007
  * created by cpanspec 1.78.07
